#include <avr/io.h>
#include <avr/interrupt.h>
#include <portbits.h>
#include "global.h"
#include "uart.h"

#define XTAL_CPU        16000000
#define UART_BAUD_RATE    200000

#define ODDEVEN PIND_3

volatile unsigned short spalte;
volatile unsigned char oddeven, sync;

int main(void)
{
	uart_init(UART_BAUD_SELECT(UART_BAUD_RATE, XTAL_CPU));

	DIDR0=255;
	PORTB=255;
	PORTD=255;

	ADMUX=(1<<REFS0)|(1<<REFS1)|(1<<ADLAR);		// ADC0, 1,1V Ref
	ADCSRA=(1<<ADEN)|(1<<ADATE)|(1<<ADIE)|6;	// ADC enable, 250kHz ADC clock
	ADCSRB=5;									// Output Compare 1B

	EICRA=(1<<ISC01)|(1<<ISC00);				// fallende Ecke von VSync

	sei();

	for (;;)
	{	unsigned char c;
		c=uart_getchar();
		if (c==10)
		{
		}
		else if (c==65)
		{	oddeven=0;
			spalte=0;
			TCNT1=0;
			TCCR1A=0;
			OCR1B=0;
			while (ODDEVEN);
			EIMSK=(1<<INT0);
			TCCR1B=(0<<ICNC1)|1;
			TIMSK1=(1<<ICIE1);
			while (spalte<900);
			EIMSK=0;
			TCCR1B=0;
			TIMSK1=0;
		}
	}
}

ISR(SIG_INTERRUPT0) __attribute__((interrupt));
ISR(SIG_INTERRUPT0)
{	if (oddeven)
	{	oddeven=0;
	}
	else
	{	oddeven=1;
		spalte++;
	}
	sync=1;
}

ISR(SIG_INPUT_CAPTURE1)
{	OCR1B=ICR1+spalte+32;						// Verzgerung seit fallender Flanke von HSync einstellen
	if (spalte>500)
		TIMSK1=0;
}

//ISR(SIG_ADC) __attribute__((interrupt));
ISR(SIG_ADC)
{	unsigned char adcv;
	adcv=ADCH;
	TIFR1=1<<OCF1B;
	if (sync)
	{	sync=0;
		adcv=0;
	}
	else if (adcv==0)
		adcv=1;
	UDR0=adcv;
	TIMSK1=(1<<ICIE1);
}

